import { Server } from "socket.io";
import {TSocket} from "../../../utilities/Types";
import ZoneRepository from "../../../repositories/ZoneRepository";
import ZoneManager from "../../../ZoneManager";
import {Character, Zone} from "@prisma/client";

interface IPayload {
    zoneId: number;
}

/**
 * Handle game master zone delete event
 * @param socket
 * @param io
 */
export default function (socket: TSocket, io: Server) {
    socket.on('gm:zone_editor:zone:delete', async (data: IPayload, callback: (response: boolean) => void) => {

        if (socket.character?.role !== 'gm') {
            console.log(`---Character #${socket.character?.id} is not a game master.`);
            return;
        }

        console.log(`---GM ${socket.character?.id} has deleted a zone via zone editor.`);

        try {
            const zone = await ZoneRepository.getById(data.zoneId);

            if (!zone) {
                console.log(`---Zone not found.`);
                return;
            }

            await ZoneRepository.delete(data.zoneId);

            callback(true);
        } catch (e) {
            console.error(e);
            callback(false);
        }
    });
}